@@ -1,4 +1,4 @@
-# $Id: hdfv.tcl,v 1.11 1996/08/06 08:07:06 yotam Exp yotam $
+# $Id: hdfv.tcl,v 1.13 1997/05/31 08:43:30 yotam Exp yotam $
 #
 #  HDF viewer
 #
@@ -143,7 +143,7 @@ proc setIcon {win iconWin iconName} {
          toplevel $iconWin;                                      #dpts setIc3
          label $iconWin.lbl -image $hdfvGlob(iconImage);
          pack $iconWin.lbl;
-      }								 #dpts setIc4;
+      }
       wm iconwindow $win $iconWin;
       wm iconname $win $iconName;
       # wm iconname $iconWin iconName;
@@ -196,31 +196,8 @@ proc destroyCallback {win} {
 # Warning. Wait for User's OK
 ########################################################################
 proc warn {msg} {
-   global hdfvGlob;
-   #dpts "warn: $msg";
-   # set f [topLvlFixedIcon .hdfvWarn "HDFV - Warning" Warn -borderwidth 10];
-   set f [toplevel .hdfvWarn -borderwidth 10];
-   wm transient $f .;
-
-   # button $f.ok -text OK ai-command {[list set hdfvGlob(warnOK) 1]};
-   button $f.ok -text OK -command {set hdfvGlob(warnOK) 1};
-   pack $f.ok -side bottom -fill x;
-
-   set lbl [label $f.lbl -bitmap warning];
-   pack $lbl -side left -padx 20;
-   message $f.msg -aspect 600 -text [format "hdfv: %s" $msg];
-   pack $f.msg -side top -fill x;
-
-   focus $f.ok;
-   set currGrab [grab current $f];
-   update;
-   grab $f.ok;
-   tkwait variable hdfvGlob(warnOK);
-   grab release $f.ok;
-   if [string compare $currGrab ""] {
-      grab $currGrab;
-   }
-   destroy $f;
+   tk_messageBox -icon warning -message $msg \
+      -parent . -title "HDFV - Warning" -type ok;
 }; # warn
 
 
@@ -885,6 +862,17 @@ proc groupWindow {fn gid {useWin ""}} {
 }; # groupWindow
 
 
+########################################################################
+# Select File and load
+########################################################################
+proc selectLoadData {} {
+   global  hdfvGlob;
+   set fn [tk_getOpenFile];
+   loadData $fn;
+   return $fn;
+}; # selectLoadData
+
+
 ########################################################################
 # Load HDF File
 ########################################################################
@@ -1114,10 +1102,44 @@ proc setWidgetsState {hdfvGlobKey args} {
 }; # setWidgetsState
 
 
+########################################################################
+# Valid regular expression - I wish TCL would do it without catch
+########################################################################
+proc regexpOK {re} {
+   # puts "regexpOK re=$re";
+   set ok 1;
+   if {[catch {regexp -- $re any}]} {
+      set ok 0;
+   }
+   return $ok;
+}; # regexpOK
+
+
+########################################################################
+# Validate Search expression
+########################################################################
+proc searchExpOK {} {
+   global hdfvGlob;
+   set ok 1;
+   foreach nc {name class} {
+      if {$ok && $hdfvGlob($nc.searchActive)} {
+         if {$hdfvGlob($nc.regExpActive)} {
+            set re $hdfvGlob($nc.searchEntry);
+            set ok [regexpOK $re];
+            if {!$ok} {
+               warn "Illegal Regular Expression in $nc: $re";
+            }
+         }
+      }
+   }
+   return $ok;
+}; # searchExpOK
+
+
 ########################################################################
 # Do the Vgroup/Vdata search by scanning
 ########################################################################
-proc searchScanID {nmData gd} {
+proc doSearchScanID {nmData gd} {
    #dpts "searchScanID: nmData=$nmData gd=$gd";
    global hdfvGlob;
 
@@ -1202,6 +1224,16 @@ proc searchScanID {nmData gd} {
 }; # searchScanID
 
 
+########################################################################
+# Check valid expression and call Vgroup/Vdata search
+########################################################################
+proc searchScanID {nmData gd} {
+   if {[searchExpOK]} {
+      doSearchScanID $nmData $gd;
+   }
+}; # searchScanID
+
+
 ########################################################################
 # Show selected Vgroup or Vdata from search listbox
 ########################################################################
@@ -1371,9 +1403,11 @@ for scientific data. It is defined with C & Fortran API by NCSA.\n";
       $t insert end "\nHDFV uses Tcl/Tk which is available from:\n"
       $t insert end /anonymous@ftp.smli.com:/pub/tcl/" fixed;
       $t insert end  "\n\nHDFV is written by Yotam Medini  ";
-      $t insert end  " (yotam@sj-coop.net).\n" fixed;
+      $t insert end  " (yotam@blueneptune.com).\n" fixed;
       $t insert end  "It is available from:\n";
-      $t insert end  "/anonymous@ftp.sj-coop.net:/pub/users/yotam/\n" fixed;
+      $t insert end  "/anonymous@ftp.blueneptune.com:/pub/users/yotam/\n" fixed;
+      $t insert end  "See also: http://www.blueneptune.com/~yotam/hdfv.html";
+      $t configure -state disabled;
       $t configure -state disabled;
    }
 }; # about
@@ -1383,7 +1417,7 @@ for scientific data. It is defined with C & Fortran API by NCSA.\n";
 # Main Window
 ########################################################################
 proc hdfvMain {args} {
-   global hdfvGlob;
+   global hdfvGlob DEBUG tk_strictMotif;
    #dpts "hdfvMain: args=$args";
 
    # set arg0  for sarching files
@@ -1397,6 +1431,7 @@ proc hdfvMain {args} {
    set hdfvGlob(MaxField) 40;
    set hdfvGlob(cacheSize)   128;
    set hdfvGlob(minSizeSeek) 512; # above this we will have seek function
+   set tk_strictMotif 1;
 
    # Fonts
    option add Hdfv*font            -Adobe-Helvetica-Bold-R-Normal--*-120-*
@@ -1426,10 +1461,8 @@ proc hdfvMain {args} {
    pack $f -side left -padx 10 -pady 6;
    set m [menu $mb.file.menu -tearoff 0];
    set hdfvGlob(fileMenu) $m;
-   $m add command -label Open... -command { \
-      loadData \
-               [yfs "Load HDF file:" "HDFV - File Selector" *.*df \
-	        setIcon {.yfsIcon Open}] };
+
+   $m add command -label Open... -command [list selectLoadData];
 
    $m add command -label "Reopen Current" -command hdfvReopen -state disabled;
    set hdfvGlob(reopIndex) 1;
@@ -1437,6 +1470,11 @@ proc hdfvMain {args} {
    $m add separator;
    $m add command -label Exit -command hdfvExit;
 
+   if {$DEBUG} {
+      $m add separator;
+      $m add command -label "Reload Tcl-code" -command [list source hdfv.tcl];
+   }
+
    ##########
    searchMenu $mb;
 
